import { OT, pipe, S } from '@contentlayer/utils/effect';
import { NotionClient } from '../services.js';
import { UnknownNotionError } from './errors.js';
export const fetchDatabasePages = ({ databaseTypeDef }) => pipe(S.service(NotionClient), S.chain((client) => S.async(async (emit) => {
    let nextCursor = undefined;
    do {
        const res = await client.databases.query({
            database_id: databaseTypeDef.databaseId,
            start_cursor: nextCursor ?? undefined,
            filter: databaseTypeDef.query?.filter,
            sorts: databaseTypeDef.query?.sorts,
        });
        nextCursor = res.next_cursor; // NOTE: Throw type error and make res any if not typed, why???
        emit.single(res.results);
    } while (nextCursor);
    emit.end();
})), OT.withStreamSpan('@contentlayer/source-notion/fetchData:fetchDatabasePages'), S.mapError((error) => new UnknownNotionError({ error })));
//# sourceMappingURL=fetchDatabasePages.js.map