import { OT, pipe, T } from '@contentlayer/utils/effect';
import { NotionClient } from '../services.js';
import { provideFieldDef } from './provideFieldDef.js';
export const provideDocumentTypeDef = ({ databaseTypeDef, getDocumentTypeDef, options }) => pipe(T.service(NotionClient), T.chain((client) => pipe(T.tryPromise(() => client.databases.retrieve({ database_id: databaseTypeDef.databaseId })), T.map(({ properties }) => Object.values(properties)), T.chain((properties) => T.forEachPar_(properties, (property) => provideFieldDef({ databaseTypeDef, property, getDocumentTypeDef }))))), T.map((fieldDefsChunk) => {
    const fieldDefs = [...fieldDefsChunk].filter((fd) => fd);
    if (databaseTypeDef.importContent !== false) {
        fieldDefs.push({
            name: options.fieldOptions.bodyFieldName,
            type: 'nested',
            nestedTypeName: 'Body',
            description: 'The page content',
            isRequired: true,
            isSystemField: true,
            default: undefined,
        });
    }
    const computedFields = Object.entries(databaseTypeDef.computedFields ?? {}).map(([name, computedField]) => ({
        description: computedField.description,
        type: computedField.type,
        name,
        // NOTE we need to flip the variance here (casting a core.Document to a LocalDocument)
        resolve: computedField.resolve,
    }));
    return {
        _tag: 'DocumentTypeDef',
        name: databaseTypeDef.name,
        description: databaseTypeDef.description,
        isSingleton: false,
        fieldDefs: fieldDefs,
        computedFields: computedFields,
        extensions: {},
    };
}), OT.withSpan('@contentlayer/source-notion/schema:provideDocumentTypeDef'));
//# sourceMappingURL=provideDocumentTypeDef.js.map